@@ -17,7 +17,16 @@ class GitHelper:
     def commit_message() -> str:
         return git["log", -1, "--pretty=%B"]().strip()
 
+    @staticmethod
+    def remote_url():
+        url = git['config', 'remote.origin.url']().strip()
+        return url.replace('ssh://', '') \
+            .replace('git@', 'https://') \
+            .replace('com:', 'com/') \
+            .replace('.git', '')
+
 
 if __name__ == "__main__":
     print("Git hash:", GitHelper.commit_hash())
     print("Git message:", GitHelper.commit_message())
+    print("Git remote url:", GitHelper.remote_url())
