@@ -71,3 +71,16 @@ class UbuntuVersionTagger(TaggerInterface):
         for line in os_release:
             if line.startswith("VERSION_ID"):
                 return "ubuntu-" + line.split("=")[1].strip('"')
+
+
+class PythonVersionTagger(TaggerInterface):
+    @staticmethod
+    def tag_value(container) -> str:
+        error = None
+        for py in ['python', 'python3', 'python2']:
+            try:
+                return "python-" + get_program_version(container, py).split()[1]
+            except AssertionError as e:
+                error = e
+        else:
+            raise error
